@@ -20,7 +20,6 @@ from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 from trytond.pyson import Eval
 from trytond.config import CONFIG
-from trytond.tools import get_smtp_server
 from trytond import backend
 
 
@@ -138,6 +137,13 @@ class Task:
         }
     )
 
+    @staticmethod
+    def default_progress_state():
+        '''
+        Default for progress state
+        '''
+        return 'Backlog'
+
     def get_all_participants(self, name):
         """
         Returns all the nereid user which are participants in the project
@@ -183,7 +189,7 @@ class Task:
         if not tasks:
             raise abort(404)
 
-        if not tasks[0].parent.can_write(request.nereid_user):
+        if not tasks[0].parent.can_write(request.nereid_user, silent=True):
             # If the user is not allowed to access this project then dont let
             raise abort(403)
 
@@ -324,6 +330,8 @@ class Task:
 
         :param receivers: Receivers of email.
         """
+        EmailQueue = Pool().get('email.queue')
+
         subject = "[#%s %s] - %s" % (
             self.id, self.parent.rec_name, self.rec_name
         )
@@ -349,9 +357,10 @@ class Task:
         )
 
         # Send mail.
-        server = get_smtp_server()
-        server.sendmail(CONFIG['smtp_from'], receivers, message.as_string())
-        server.quit()
+        EmailQueue.queue_mail(
+            CONFIG['smtp_from'], receivers,
+            message.as_string()
+        )
 
     @classmethod
     @route('/task-<int:task_id>/-unwatch', methods=['GET', 'POST'])
